import { Construct } from 'constructs';
import * as k8s from './imports/k8s';
import { PlonePDBOptions } from './pdb';
export interface PloneBackendDeploymentOptions {
    /**
     * Specify a custom image for Plone Backend.
     * @default "plone/plone-backend:latest"
     */
    readonly image?: string;
    /**
   * Number of replicas.
   * @default 2
   */
    readonly replicas?: number;
    /**
     * Port number.
     * @default 8080
     */
    readonly port?: number;
    /**
     * Extra labels to associate with resources.
     * @default - none
     */
    readonly labels?: {
        [name: string]: string;
    };
    /**
     * Extra container spec to use for ploencontainer.
     * @default - []
     */
    readonly ploneContainer?: k8s.Container;
    /**
     * Sidecar container spec to associate with resources.
     * @default - []
     */
    readonly sidecarContainers?: k8s.Container[];
    /**
     * Create a PodDisruptionBugdet for the deployment?
     * If given
     * @default - none
     */
    readonly pdb?: PlonePDBOptions;
}
export declare class PloneBackendDeployment extends Construct {
    constructor(scope: Construct, id: string, options?: PloneBackendDeploymentOptions);
}
